ChiantiPy Documentation — ChiantiPy 0.15.0 documentation

# ChiantiPy Documentation

Welcome to the ChiantiPy documentation. ChiantiPy is a pure Python package for performing calculations of astrophysical spectra using the CHIANTI atomic database.

The latest version of ChiantiPy is 0.15.0 and is compatible with CHIANTI database version 10.0.X. It is not compatible with previous versions

ChiantiPy v0.15.0 is released under the OSI approved ISC license. From Wikipedia: The ISC license is a permissive free software license written by the Internet Software Consortium (ISC). It is functionally equivalent to the simplified BSD and MIT/Expat licenses, …

CHIANTI consists of a database of atomic data that can be used to interpret spectral lines and continua emitted from high-temperature, optically-thin astrophysical sources.

CHIANTI is developed and maintained by scientists at George Mason University (USA), the University of Michigan (USA), and the University of Cambridge (UK). The first version of CHIANTI was released in 1997 and version 10.0 in 2021.

- Getting started with ChiantiPy
  - Prerequisites
  - Install the CHIANTI database
  - Install the Prerequisites
  - Install the ChiantiPy package
  - Note - ChiantiPy interactions with various GUI backends
- Quick Start
  - Setting default values
  - Level populations
  - A ChiantiPy Convention
  - Spectral Line Intensities
  - The effect of electron density on line intensities
  - G(n,T) function
  - Ionization Equilibrium
  - Intensity Ratios
  - Spectra of a single ion
  - Using emission measures (EM)
  - Free-free and free-bound continuum
  - The multi-ion class Bunch
  - Spectra of multiple ions and continuum
  - Using differential emission measures (DEM)
  - Radiative loss rate
  - Jupyter Notebooks
- Tutorial
  - The ChiantiPy Approach
  - The ion class, basic properties
- ChiantiPy’s API documentation
  - ChiantiPy package
- Indices and tables
- Notes
  - Setting default values
  - Setting minAbund in spectrum calculations
- Intro for CHIANTI IDL Users
- Resources for ChiantiPy Users
  - Forums
- Changelog
  - Changes from 0.14.1 to 0.15.0
  - Changes from 0.14.0 to 0.14.1
  - Changes from 0.13.1 to 0.14.0
  - Changes from 0.13.0 to 0.13.1
  - Changes from 0.12.0 to 0.13.0
  - Changes from 0.11.0 to 0.12.0
  - Changes from 0.10.0 to 0.11.0
  - Changes from 0.9.5 to 0.10.0
  - Changes from 0.9.4 to 0.9.5
  - Changes from 0.9.3 to 0.9.4
  - Changes from 0.9.3 to 0.9.3
  - Changes from 0.9.2 to 0.9.3
  - Changes from 0.9.1 to 0.9.2
  - Changes from 0.9.0 to 0.9.1
  - Changes from 0.8.7 to 0.9.0
  - Changes from 0.8.6 to 0.8.7
  - Changes from 0.8.5 to 0.8.6
  - Changes from 0.8.4 to 0.8.5
  - This is a major bug-fix release.
  - Changes from 0.8.3 to 0.8.4
  - This is a major bug-fix release.
  - Changes from 0.7.1 to 0.8.3
  - This is a major bug-fix release.
  - Version 0.8.x files are necessary to use with the new CHIANTI Version 9.0 database
  - changes from 0.7.1 to 0.8.0
  - changes from 0.7.0 to 0.7.1
  - changes from 0.6.5 to 0.7.0
  - changes from 0.6.0 to 0.6.5
  - changes from 0.5.3 to 0.6.0
- Reporting Bugs

# Indices and tables

- Index

- Module Index

- Search Page